==> krb4-0.9.1.tar.gz: krb4-0.9.1/lib/krb/get_phost.c <==
/*
 * This software may now be redistributed outside the US.
 *
 */

/* 
   Copyright (C) 1989 by the Massachusetts Institute of Technology

   Export of this software from the United States of America is assumed
   to require a specific license from the United States Government.
   It is the responsibility of any person or organization contemplating
   export to obtain such a license before exporting.

   WITHIN THAT CONSTRAINT, permission to use, copy, modify, and
   distribute this software and its documentation for any purpose and
   without fee is hereby granted, provided that the above copyright
   notice appear in all copies and that both that copyright notice and
   this permission notice appear in supporting documentation, and that
   the name of M.I.T. not be used in advertising or publicity pertaining
   to distribution of the software without specific, written prior
   permission.  M.I.T. makes no representations about the suitability of
   this software for any purpose.  It is provided "as is" without express
   or implied warranty.
   
   */

#include "krb_locl.h"

RCSID("$Id: get_phost.c,v 1.7 1996/04/26 11:39:22 d91-jda Exp $");

/*
 * This routine takes an alias for a host name and returns the first
 * field, lower case, of its domain name.  For example, if "menel" is
 * an alias for host officially named "menelaus" (in /etc/hosts), for
 * the host whose official name is "MENELAUS.MIT.EDU", the name "menelaus"
 * is returned.
 */

static char phost[MaxHostNameLen+1];

char *
krb_get_phost(char *alias)
{
    char *p;
    
    k_name_to_name(alias, phost);

    p = strtok(phost, ".");
    while(*p){
	if(isupper(*p)) *p=tolower(*p);
	p++;
    }
    return phost;
}

==> krb4-0.9.2a.tar.gz: krb4-0.9.2a/lib/krb/get_phost.c <==
/*
 * This software may now be redistributed outside the US.
 *
 */

/* 
   Copyright (C) 1989 by the Massachusetts Institute of Technology

   Export of this software from the United States of America is assumed
   to require a specific license from the United States Government.
   It is the responsibility of any person or organization contemplating
   export to obtain such a license before exporting.

   WITHIN THAT CONSTRAINT, permission to use, copy, modify, and
   distribute this software and its documentation for any purpose and
   without fee is hereby granted, provided that the above copyright
   notice appear in all copies and that both that copyright notice and
   this permission notice appear in supporting documentation, and that
   the name of M.I.T. not be used in advertising or publicity pertaining
   to distribution of the software without specific, written prior
   permission.  M.I.T. makes no representations about the suitability of
   this software for any purpose.  It is provided "as is" without express
   or implied warranty.
   
   */

#include "krb_locl.h"

RCSID("$Id: get_phost.c,v 1.8 1996/08/20 13:03:20 bg Exp $");

/*
 * This routine takes an alias for a host name and returns the first
 * field, lower case, of its domain name.  For example, if "menel" is
 * an alias for host officially named "menelaus" (in /etc/hosts), for
 * the host whose official name is "MENELAUS.MIT.EDU", the name "menelaus"
 * is returned.
 */

char *
krb_get_phost(const char *alias)
{
  static char phost[MaxHostNameLen+1];
  char *p;
    
  k_name_to_name(alias, phost);

  p = strtok(phost, ".");
  while (*p) {
    if (isupper(*p))
      *p = tolower(*p);
    p++;
  }
  return phost;
}
